"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const schematics_1 = require("@angular-devkit/schematics");
const workspace_1 = require("@nrwl/workspace");
const flutter_utils_1 = require("../../utils/flutter-utils");
const generate_project_1 = require("./lib/generate-project");
const normalize_options_1 = require("./lib/normalize-options");
/**
 * Depending on your needs, you can change this to either `Library` or `Application`
 */
const projectType = workspace_1.ProjectType.Application;
function default_1(options) {
    if (!flutter_utils_1.isFlutterInstalled()) {
        throw new Error("'flutter' was not found on your system's PATH.\nPlease make sure you have installed it correctly.\n👉🏾 https://flutter.dev/docs/get-started/install");
    }
    const normalizedOptions = normalize_options_1.normalizeOptions(options);
    return schematics_1.chain([
        workspace_1.updateWorkspace((workspace) => {
            const project = workspace.projects
                .add({
                name: normalizedOptions.projectName,
                root: normalizedOptions.projectRoot,
                sourceRoot: `${normalizedOptions.projectRoot}/src`,
                projectType,
            });
            const commands = [
                { key: 'analyze', value: 'analyze' },
                { key: 'assemble', value: 'assemble' },
                { key: 'attach', value: 'attach' },
                //build commands
                { key: 'buildApk', value: 'build apk' },
                { key: 'buildAppbundle', value: 'build appbundle' },
                { key: 'buildBundle', value: 'build bundle' },
                { key: 'buildIos', value: 'build ios' },
                { key: 'buildIosFramework', value: 'build ios-framework' },
                { key: 'buildIpa', value: 'build ipa' },
                { key: 'clean', value: 'clean' },
                { key: 'drive', value: 'drive' },
                { key: 'format', value: `format ${normalizedOptions.projectRoot}/*` },
                { key: 'genL10n', value: 'gen-l10n' },
                { key: 'install', value: 'install' },
                { key: 'run', value: 'run' },
                { key: 'test', value: 'test' },
            ];
            commands.forEach(e => {
                project.targets.add({
                    name: `${e.key}`,
                    builder: '@nrwl/workspace:run-commands',
                    options: {
                        command: `flutter ${e.value}`,
                        cwd: normalizedOptions.projectRoot
                    }
                });
            });
        }),
        workspace_1.addProjectToNxJsonInTree(normalizedOptions.projectName, {
            tags: normalizedOptions.parsedTags,
        }),
        generate_project_1.generateProject(normalizedOptions)
    ]);
}
exports.default = default_1;
//# sourceMappingURL=schematic.js.map